from setuptools import setup

setup(name='gaus_bino_dist',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['gaus_bino_dist'],
      author='Maitrey Talware',
      zip_safe=False)
